import requests

try:
    import json
except ImportError:
    import simplejson as json

class APIException(Exception):
    pass

class HTTPException(Exception):
    pass

class SmsIR(object):
    def __init__(self, UserApiKey,SecretKey):
        self.version = 'v1'
        self.host = 'RestfulSms.com/api'
        self.headers = {
	    'Content-Type': 'application/json',
        'charset': 'utf-8'
        }
        self.bodies = {
            "UserApiKey": UserApiKey,
            "SecretKey": SecretKey
        }
        self.TokenUrl = 'https://RestfulSms.com/api/Token'    
        self.TokenKey = ""
        try:
            content = requests.post(self.TokenUrl , headers=self.headers, json = self.bodies).content
            try:
                response = json.loads(content.decode("utf-8"))
                print("IsSuccessful : " + str(response["IsSuccessful"]))
                print("Message : " + response["Message"])
                print("----------------------")
                print("TokenKey : \n" + response["TokenKey"])
                print("----------------------")
                self.TokenKey = response["TokenKey"]
            except ValueError as e:
                raise HTTPException(e)
        except requests.exceptions.RequestException as e:
            raise HTTPException(e)

    def otp(self,MobileNumber, Code):
        url = "https://RestfulSms.com/api/VerificationCode"
        headers = {
        'Content-Type': 'application/json',
        'x-sms-ir-secure-token':self.TokenKey,
        'charset': 'utf-8',
        }
        bodies = {
            "Code": Code,
            "MobileNumber": MobileNumber,
        }
        try:
            content = requests.post(url , headers=headers, json = bodies).content
            try:
                response = json.loads(content.decode("utf-8"))
                print("VerificationCodeId : " + str(response["VerificationCodeId"]))
                print("IsSuccessful : " + str(response["IsSuccessful"]))
                print("Message : " + response["Message"])
                print("Verification Code is: ",Code)
            except ValueError as e:
                raise HTTPException(e)
        except requests.exceptions.RequestException as e:
            raise HTTPException(e)

# tt = SmsAPI("14769c3b5e4af9518bd69c4","it66)%#teBC!@*&123445")
# tt.otp("09150938139","951234")


    def getToken(self,UserApiKey,SecretKey):
        host = 'RestfulSms.com/api'
        headers = {
	    'Content-Type': 'application/json',
        'charset': 'utf-8'
        }
        bodies = {
            "UserApiKey": UserApiKey,
            "SecretKey": SecretKey
        }
        TokenUrl = 'https://RestfulSms.com/api/Token'  
        TokenKey = ""
        try:
            content = requests.post(TokenUrl , headers=headers, json = bodies).content
            try:
                response = json.loads(content.decode("utf-8"))
                print("IsSuccessful : \n" + str(response["IsSuccessful"]))
                print("Message : \n" + response["Message"])
                print("TokenKey : \n" + response["TokenKey"])
                self.TokenKey = response["TokenKey"]
            except ValueError as e:
                raise HTTPException(e)
        except requests.exceptions.RequestException as e:
            raise HTTPException(e)



import setuptools
import sys

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="smsiran",
    version="0.0.1",
    author="Soroush piri zendedel",
    author_email="soroush_zendedel@live.com",
    keywords=["SMS","Persian","iran","web service","sms web service"],
    description="A library for using SMS web services in IRAN",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/avanditc/smsiran",
    download_url = 'https://github.com/avanditc/smsiran/archive/refs/tags/v0.0.1.tar.gz',
    project_urls={
        "Bug Tracker": "https://github.com/avanditc/smsiran/issues",
        "Owner": "https://AvandITC.ir",
    },
    classifiers=[
        "Development Status :: 1 - Planning",
        'Intended Audience :: Developers',
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    license="MIT",
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    install_requires=[
        'requests',
        'json',
    ],
    python_requires=">=3.6",
)